@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# $Id: mplayer.pl,v 1.14 2006/02/13 17:42:46 khlut Exp $
+# $Id: mplayer.pl,v 1.19 2006/03/19 20:19:27 khlut Exp $
 # Bind mplayer and mencoder with HTML object
 # ElphelOgm is used to receive and record rtp mjpeg video
 #
@@ -73,7 +73,7 @@ sub shut{
 	kill 2 => $sl2p if $sl2p;
     }else{			#if it again not respond kill it
         kill -9 => $slvp;
-	kill -9 => $sl2p if $sl2p;
+	kill(-9 => $sl2p) || print "kill_error: $!\n" if $sl2p;
 	print "\nrun=0\n";    
 	exit 0;	
     }
@@ -127,6 +127,17 @@ sub ifilt{
 		lock $queue;
 		$queue.="pause=$val\nplay=".(1-$val)."\n";
 	    }	    
+	}elsif( $var eq "filepos" ) {
+	    if($val =~ s/%//) {
+		print SLVW "seek $val 1\n";
+	    }else{
+		print SLVW "seek $val 2\n";
+	    }
+	}elsif( $var eq "framestep" ) {
+	    print SLVW "frame_step\n";	    
+	    $pausestate=1;
+	    lock $queue;
+	    $queue.="pause=1\nplay=0\n";
 	}elsif( $var eq "src" or $var eq "href") {
 	    $v{href}=$val;
 	    print SLVW "loadfile $val\n";
@@ -209,12 +220,14 @@ sub run_mencoder{
     return $slvp>0;
 }
 sub rtpcmd{
-    return $v{type} =~ m|^video/m| && $v{href} =~ m|^rtp://([0-9.]+):([0-9]+)/?$|
+    return $v{type} =~ m!^video/m|^application/.*elphel-ogm! && $v{href} =~ m|^rtp://([0-9.]+):([0-9]+)/?$|
 	&& "ElphelOgm -a$1 -p$2 -s2000000";
 }
 
 print "debug=1\n", # list of control variables
       "pause=0\n",
+      "framestep=\n",
+      "filepos=\n",
       "play=1\n",
       "save=\n",
       "fps=\n",
@@ -277,7 +290,7 @@ while (<STDIN>){
 	    $OPTS.=" -fixed-vo -loop ".(0+$v{loop}) if( exists $v{loop} );
 	    if(( $cmd2=rtpcmd() )) {
 		$cmd2.=" -k $v{frameskip}" if $v{frameskip};
-	        $cmd2="|exec $cmd2 2>/dev/null ".fileno(PIPE_OUT)."<&- >/dev/fd/".fileno(PIPE_IN);
+	        $cmd2="|exec $cmd2 -i 2>/dev/null ".fileno(PIPE_OUT)."<&- >/dev/fd/".fileno(PIPE_IN);
 		$cmd="mplayer $OPTS -vo $cfg{vo}[0] -zoom -nojoystick -slave -nomouseinput -cookies -nocache /dev/fd/".fileno(PIPE_OUT);
 	        print "cmd=$cmd\n";
 	        print "cmd2=$cmd2\n";
